@@ -1,6 +1,6 @@
-trainControl <- function(
-                         method = "boot",
-                         number = ifelse(method == "cv", 10, 25),
+trainControl <- function(method = "boot",
+                         number = ifelse(method %in% c("cv", "repeatedcv"), 10, 25),
+                         repeats = ifelse(method %in% c("cv", "repeatedcv"), 1, number),
                          verboseIter = TRUE,
                          returnData = TRUE,
                          returnResamp = "final",
@@ -8,6 +8,9 @@ trainControl <- function(
                          classProbs = FALSE,
                          summaryFunction = defaultSummary,
                          selectionFunction = "best",
+                         PCAthresh = 0.95,
+                         ICAcomp = 3,
+                         k = 5,
                          index = NULL,
                          workers = 1,
                          computeFunction = lapply,
@@ -15,9 +18,9 @@ trainControl <- function(
 {
   if(is.null(selectionFunction)) stop("null selectionFunction values not allowed")
   if(!(returnResamp %in% c("all", "final", "none"))) stop("incorrect value of returnResamp")
-  list(
-       method = method,
+  list(method = method,
        number = number,
+       repeats = repeats,
        verboseIter = verboseIter,
        returnData = returnData,
        returnResamp = returnResamp,
@@ -25,6 +28,9 @@ trainControl <- function(
        classProbs = classProbs,
        summaryFunction = summaryFunction,
        selectionFunction = selectionFunction,
+       PCAthresh = PCAthresh,
+       ICAcomp = ICAcomp,
+       k = k,
        index = index,
        workers = workers,
        computeFunction = computeFunction,
